# Random Unicode Emoji

[![Python](https://img.shields.io/pypi/pyversions/random-unicode-emoji)](https://pypi.org/project/random-unicode-emoji/)
[![PyPI Version](https://img.shields.io/pypi/v/random-unicode-emoji)](https://pypi.org/project/random-unicode-emoji/)
[![Downloads](https://pepy.tech/badge/random-unicode-emoji)](https://pepy.tech/project/random-unicode-emoji)
[![GitHub Repo stars](https://img.shields.io/github/stars/NicPWNs/random-unicode-emoji)](https://github.com/NicPWNs/random_unicode_emoji/stargazers)
[![Forks](https://img.shields.io/github/forks/NicPWNs/random-unicode-emoji.svg)](https://github.com/NicPWNs/random-unicode-emoji/forks)
[![GitHub Repo size](https://img.shields.io/github/repo-size/NicPWNs/random-unicode-emoji)](https://github.com/NicPWNs/random_unicode_emoji)
[![License](https://img.shields.io/badge/license-MIT-green.svg)](https://github.com/NicPWNs/random_unicode_emoji/blob/main/LICENSE.rst)
[![Open Issues](https://img.shields.io/github/issues/NicPWNs/random-unicode-emoji.svg)](https://github.com/NicPWNs/random-unicode-emoji/issues)
[![Project Status](http://www.repostatus.org/badges/latest/active.svg)](http://www.repostatus.org/#active)

A Python package and function to retrieve a random Unicode emoji. ❤️

> Like this repo? Give it a [⭐ on GitHub!](https://github.com/NicPWNs/random_unicode_emoji)

## Install

```bash
pip install random-unicode-emoji
```

## Usage

```py
# Import the Library
from random_unicode_emoji import random_emoji
# Use the Function
print(random_emoji())
```

## Unicode

**Uses Unicode Standard [Version 15.0](https://www.unicode.org/charts/#symbols)**

_Pulls emojis from the following Unicode character sets:_

- [Miscellaneous Symbols](https://www.unicode.org/charts/PDF/U2600.pdf)
- [Miscellaneous Symbols and Pictographs](https://www.unicode.org/charts/PDF/U1F300.pdf)
- [Emoticons](https://www.unicode.org/charts/PDF/U1F600.pdf)
- [Transport and Map Symbols](https://www.unicode.org/charts/PDF/U1F680.pdf)
- [Supplemental Symbols and Pictographs](https://www.unicode.org/charts/PDF/U1F900.pdf)
- [Symbols and Pictographs Extended-A](https://www.unicode.org/charts/PDF/U1FA70.pdf)

## Maintainer

[Nic Jones, (NicPWNs)](https://github.com/NicPWNs)

## References

Inspired by [randomEmoji.py](https://gist.github.com/shello/efa2655e8a7bce52f273)
